@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2009 Jeffrey Stedfast
+ *  Copyright (C) 2000-2011 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -74,7 +74,6 @@ static struct {
 	{ "Shift-JIS",    1, 0 },  /* Japanese as used by Windows and MacOS systems */
 	{ "euc-jp",       1, 0 },  /* Japanese traditionally used on Unix systems */
 	{ "euc-kr",       1, 0 },  /* Korean */
-	{ "iso-2022-kr",  1, 0 },  /* Korean (less popular than euc-kr) */
 	{ "gb2312",       1, 0 },  /* Simplified Chinese */
 	{ "Big5",         1, 0 },  /* Traditional Chinese */
 	{ "euc-tw",       1, 0 },
@@ -117,9 +116,10 @@ int main (int argc, char **argv)
 	char *inbuf, *outbuf;
 	guint32 out[128], c;
 	char in[128];
-	int i, j, k;
-	int bytes;
 	iconv_t cd;
+	int bytes;
+	int j, k;
+	size_t i;
 	
 	/* dont count the terminator */
 	bytes = ((sizeof (tables) / sizeof (tables[0])) + 7 - 1) / 8;
@@ -134,7 +134,7 @@ int main (int argc, char **argv)
 		inleft = sizeof (in);
 		outbuf = (char *) out;
 		outleft = sizeof (out);
-		while (iconv (cd, &inbuf, &inleft, &outbuf, &outleft) == -1) {
+		while (iconv (cd, &inbuf, &inleft, &outbuf, &outleft) == (size_t) -1) {
 			if (errno == EILSEQ) {
 				inbuf++;
 				inleft--;
